@@ -20,7 +20,7 @@
 #ifndef KFILEITEMMODELROLESUPDATER_H
 #define KFILEITEMMODELROLESUPDATER_H
 
-#include <config-nepomuk.h>
+#include <config-baloo.h>
 
 #include <KFileItem>
 #include <kitemviews/kitemmodelbase.h>
@@ -38,26 +38,10 @@ class KJob;
 class QPixmap;
 class QTimer;
 
-#ifdef HAVE_NEPOMUK
-    namespace Nepomuk2
+#ifdef HAVE_BALOO
+    namespace Baloo
     {
-        class ResourceWatcher;
-        class Resource;
-        namespace Types
-        {
-            class Property;
-        }
-    }
-#else
-    // Required for the slot applyChangedNepomukRoles() that
-    // cannot be ifdefined due to moc.
-    namespace Nepomuk2
-    {
-        class Resource;
-        namespace Types
-        {
-            class Property;
-        }
+        class FileMonitor;
     }
 #endif
 
@@ -216,7 +200,8 @@ private slots:
      */
     void resolveRecentlyChangedItems();
 
-    void applyChangedNepomukRoles(const Nepomuk2::Resource& resource, const Nepomuk2::Types::Property& property);
+    void applyChangedBalooRoles(const QString& file);
+    void applyChangedBalooRolesJobFinished(KJob* job);
 
     void slotDirectoryContentsCountReceived(const QString& path, int count);
 
@@ -261,7 +246,7 @@ private:
         ResolveFast,
         ResolveAll
     };
-    bool applyResolvedRoles(const KFileItem& item, ResolveHint hint);
+    bool applyResolvedRoles(int index, ResolveHint hint);
     QHash<QByteArray, QVariant> rolesData(const KFileItem& item);
 
     /**
@@ -346,9 +331,8 @@ private:
 
     KDirectoryContentsCounter* m_directoryContentsCounter;
 
-#ifdef HAVE_NEPOMUK
-    Nepomuk2::ResourceWatcher* m_nepomukResourceWatcher;
-    mutable QHash<QUrl, KUrl> m_nepomukUriItems;
+#ifdef HAVE_BALOO
+    Baloo::FileMonitor* m_balooFileMonitor;
 #endif
 };
 
