@@ -49,7 +49,7 @@ public:
     KItemListWidgetInformant();
     virtual ~KItemListWidgetInformant();
 
-    virtual QSizeF itemSizeHint(int index, const KItemListView* view) const = 0;
+    virtual void calculateItemSizeHints(QVector<QSizeF>& sizeHints, const KItemListView* view) const = 0;
 
     virtual qreal preferredRoleColumnWidth(const QByteArray& role,
                                            int index,
@@ -108,6 +108,8 @@ public:
     void setHovered(bool hovered);
     bool isHovered() const;
 
+    void setHoverPosition(const QPointF& pos);
+
     void setAlternateBackground(bool enable);
     bool alternateBackground() const;
 
