@@ -51,22 +51,17 @@
 #include <views/dolphinview.h>
 #include <views/viewproperties.h>
 
-#ifdef HAVE_NEPOMUK
-    #include <Nepomuk2/ResourceManager>
-    #include <Nepomuk2/Query/ComparisonTerm>
-    #include <Nepomuk2/Query/LiteralTerm>
-    #include <Nepomuk2/Query/FileQuery>
-    #include <Nepomuk2/Query/ResourceTypeTerm>
-    #include <Nepomuk2/Vocabulary/NFO>
-    #include <Nepomuk2/Vocabulary/NIE>
+#ifdef HAVE_BALOO
+    #include <baloo/query.h>
+    #include <baloo/indexerconfig.h>
 #endif
 
 namespace {
     // As long as KFilePlacesView from kdelibs is available in parallel, the
     // system-bookmarks for "Recently Accessed" and "Search For" should be
     // shown only inside the Places Panel. This is necessary as the stored
-    // URLs needs to get translated to a Nepomuk-search-URL on-the-fly to
-    // be independent from changes in the Nepomuk-search-URL-syntax.
+    // URLs needs to get translated to a Baloo-search-URL on-the-fly to
+    // be independent from changes in the Baloo-search-URL-syntax.
     // Hence a prefix to the application-name of the stored bookmarks is
     // added, which is only read by PlacesItemModel.
     const char* AppNamePrefix = "-places-panel";
@@ -87,16 +82,9 @@ PlacesItemModel::PlacesItemModel(QObject* parent) :
     m_updateBookmarksTimer(0),
     m_storageSetupInProgress()
 {
-#ifdef HAVE_NEPOMUK
-    Nepomuk2::ResourceManager* rm = Nepomuk2::ResourceManager::instance();
-    connect(rm, SIGNAL(nepomukSystemStarted()), this, SLOT(slotNepomukStarted()));
-    connect(rm, SIGNAL(nepomukSystemStopped()), this, SLOT(slotNepomukStopped()));
-
-    if (rm->initialized()) {
-        KConfig config("nepomukserverrc");
-        m_fileIndexingEnabled = config.group("Service-nepomukfileindexer").readEntry("autostart", true);
-    }
-
+#ifdef HAVE_BALOO
+    Baloo::IndexerConfig config;
+    m_fileIndexingEnabled = config.fileIndexingEnabled();
 #endif
     const QString file = KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml");
     m_bookmarkManager = KBookmarkManager::managerForFile(file, "kfilePlaces");
@@ -959,35 +947,6 @@ void PlacesItemModel::clear() {
     KStandardItemModel::clear();
 }
 
-void PlacesItemModel::slotNepomukStarted()
-{
-    KConfig config("nepomukserverrc");
-    m_fileIndexingEnabled = config.group("Service-nepomukfileindexer").readEntry("autostart", true);
-    if (m_fileIndexingEnabled) {
-        m_systemBookmarks.clear();
-        m_systemBookmarksIndexes.clear();
-        createSystemBookmarks();
-
-        clear();
-        loadBookmarks();
-    }
-}
-
-void PlacesItemModel::slotNepomukStopped()
-{
-    if (m_fileIndexingEnabled) {
-        m_fileIndexingEnabled = false;
-
-        m_systemBookmarks.clear();
-        m_systemBookmarksIndexes.clear();
-        createSystemBookmarks();
-
-        clear();
-        loadBookmarks();
-    }
-}
-
-
 void PlacesItemModel::initializeAvailableDevices()
 {
     QString predicate("[[[[ StorageVolume.ignored == false AND [ StorageVolume.usage == 'FileSystem' OR StorageVolume.usage == 'Encrypted' ]]"
@@ -1145,7 +1104,7 @@ bool PlacesItemModel::equalBookmarkIdentifiers(const KBookmark& b1, const KBookm
 
 KUrl PlacesItemModel::createTimelineUrl(const KUrl& url)
 {
-    // TODO: Clarify with the Nepomuk-team whether it makes sense
+    // TODO: Clarify with the Baloo-team whether it makes sense
     // provide default-timeline-URLs like 'yesterday', 'this month'
     // and 'last month'.
     KUrl timelineUrl;
@@ -1195,18 +1154,16 @@ KUrl PlacesItemModel::createSearchUrl(const KUrl& url)
 {
     KUrl searchUrl;
 
-#ifdef HAVE_NEPOMUK
+#ifdef HAVE_BALOO
     const QString path = url.pathOrUrl();
     if (path.endsWith(QLatin1String("documents"))) {
-        searchUrl = searchUrlForTerm(Nepomuk2::Query::ResourceTypeTerm(Nepomuk2::Vocabulary::NFO::Document()));
+        searchUrl = searchUrlForType("Document");
     } else if (path.endsWith(QLatin1String("images"))) {
-        searchUrl = searchUrlForTerm(Nepomuk2::Query::ResourceTypeTerm(Nepomuk2::Vocabulary::NFO::Image()));
+        searchUrl = searchUrlForType("Image");
     } else if (path.endsWith(QLatin1String("audio"))) {
-        searchUrl = searchUrlForTerm(Nepomuk2::Query::ComparisonTerm(Nepomuk2::Vocabulary::NIE::mimeType(),
-                                                                    Nepomuk2::Query::LiteralTerm("audio")));
+        searchUrl = searchUrlForType("Audio");
     } else if (path.endsWith(QLatin1String("videos"))) {
-        searchUrl = searchUrlForTerm(Nepomuk2::Query::ComparisonTerm(Nepomuk2::Vocabulary::NIE::mimeType(),
-                                                                    Nepomuk2::Query::LiteralTerm("video")));
+        searchUrl = searchUrlForType("Video");
     } else {
         Q_ASSERT(false);
     }
@@ -1217,10 +1174,13 @@ KUrl PlacesItemModel::createSearchUrl(const KUrl& url)
     return searchUrl;
 }
 
-#ifdef HAVE_NEPOMUK
-KUrl PlacesItemModel::searchUrlForTerm(const Nepomuk2::Query::Term& term)
+#ifdef HAVE_BALOO
+KUrl PlacesItemModel::searchUrlForType(const QString& type)
 {
-    const Nepomuk2::Query::FileQuery query(term);
+    Baloo::Query query;
+    query.addType("File");
+    query.addType(type);
+
     return query.toSearchUrl();
 }
 #endif
