@@ -22,13 +22,14 @@
 
 #include <QWidget>
 
-#include <config-nepomuk.h>
-#ifdef HAVE_NEPOMUK
-    #include <Nepomuk2/Query/Term>
+#include <config-baloo.h>
+#ifdef HAVE_BALOO
+    #include <baloo/term.h>
 #endif
 
 class QButtonGroup;
 class QCheckBox;
+class QDate;
 class QRadioButton;
 
 /**
@@ -55,20 +56,22 @@ public:
     explicit DolphinFacetsWidget(QWidget* parent = 0);
     virtual ~DolphinFacetsWidget();
 
-#ifdef HAVE_NEPOMUK
-    Nepomuk2::Query::Term facetsTerm() const;
+#ifdef HAVE_BALOO
+    Baloo::Term ratingTerm() const;
+    QString facetType() const;
+
+    bool isRatingTerm(const Baloo::Term& term) const;
+    void setRatingTerm(const Baloo::Term& term);
 #endif
 
+    void setFacetType(const QString& type);
+
 signals:
     void facetChanged();
 
 private:
-    /**
-     * @return New checkbox which is connected to the
-     *         slotFacedChanged() slot whenever it has
-     *         been toggled.
-     */
-    QCheckBox* createCheckBox(const QString& text);
+    void setRating(const int stars);
+    void setTimespan(const QDate& date);
 
     /**
      * @return New radiobutton which is connected to the
@@ -79,10 +82,11 @@ private:
                                     QButtonGroup* group);
 
 private:
-    QCheckBox* m_documents;
-    QCheckBox* m_images;
-    QCheckBox* m_audio;
-    QCheckBox* m_videos;
+    QRadioButton* m_anyType;
+    QRadioButton* m_documents;
+    QRadioButton* m_images;
+    QRadioButton* m_audio;
+    QRadioButton* m_videos;
 
     QRadioButton* m_anytime;
     QRadioButton* m_today;
