@@ -74,6 +74,7 @@ class KUrlRequester;
 class KBookmarkManager;
 class KonqHistoryDialog;
 struct HistoryEntry;
+class QLineEdit;
 
 namespace KParts {
     class BrowserExtension;
@@ -614,6 +615,8 @@ private:
 
   QObject* lastFrame( KonqView *view );
 
+  QLineEdit* comboEdit();
+
 private: // members
   KonqUndoManager* m_pUndoManager;
 
